From e0477a00dfa4b81a3a2f4b0236ed6cf8e9aa17e1 Mon Sep 17 00:00:00 2001
From: TsiChungLiew <Tsi-Chung.Liew@freescale.com>
Date: Tue, 31 Jul 2007 14:21:23 -0500
Subject: [PATCH] Added uart_gpio_conf() for port configuration

Added uart_gpio_conf() in serial_init() (drivers/serial/mcfuart.c), sperated uart port configuration from cpu_init() to uart_gpio_conf()

Signed-off-by: TsiChungLiew <Tsi-Chung.Liew@freescale.com>
---
 cpu/mcf532x/cpu_init.c   |   41 ++++++++++++++++++++++++++---------------
 drivers/serial/mcfuart.c |    4 ++++
 2 files changed, 30 insertions(+), 15 deletions(-)

diff --git a/cpu/mcf532x/cpu_init.c b/cpu/mcf532x/cpu_init.c
index 32711a1..84ebb1f 100644
--- a/cpu/mcf532x/cpu_init.c
+++ b/cpu/mcf532x/cpu_init.c
@@ -60,22 +60,8 @@ void cpu_init_f(void)
 	scm2->pacrg = 0;
 	scm1->pacrh = 0;
 
-	/* Setup Ports: */
-	switch (CFG_UART_PORT) {
-	case 0:
-		gpio->par_uart = (GPIO_PAR_UART_TXD0 | GPIO_PAR_UART_RXD0);
-		break;
-	case 1:
-		gpio->par_uart =
-		    (GPIO_PAR_UART_TXD1(3) | GPIO_PAR_UART_RXD1(3));
-		break;
-	case 2:
-		gpio->par_uart = (GPIO_PAR_TIN3_URXD2 | GPIO_PAR_TIN2_UTXD2);
-		break;
-	}
-
 	/* Port configuration */
-	gpio->par_cs = 0x3E;
+	gpio->par_cs = 0;
 
 #if (defined(CFG_CS0_BASE) && defined(CFG_CS0_MASK) && defined(CFG_CS0_CTRL))
 	fbcs->csar0 = CFG_CS0_BASE;
@@ -85,30 +71,35 @@ void cpu_init_f(void)
 
 #if (defined(CFG_CS1_BASE) && defined(CFG_CS1_MASK) && defined(CFG_CS1_CTRL))
 	/* Latch chipselect */
+	gpio->par_cs |= GPIO_PAR_CS1;
 	fbcs->csar1 = CFG_CS1_BASE;
 	fbcs->cscr1 = CFG_CS1_CTRL;
 	fbcs->csmr1 = CFG_CS1_MASK;
 #endif
 
 #if (defined(CFG_CS2_BASE) && defined(CFG_CS2_MASK) && defined(CFG_CS2_CTRL))
+	gpio->par_cs |= GPIO_PAR_CS2;
 	fbcs->csar2 = CFG_CS2_BASE;
 	fbcs->cscr2 = CFG_CS2_CTRL;
 	fbcs->csmr2 = CFG_CS2_MASK;
 #endif
 
 #if (defined(CFG_CS3_BASE) && defined(CFG_CS3_MASK) && defined(CFG_CS3_CTRL))
+	gpio->par_cs |= GPIO_PAR_CS3;
 	fbcs->csar3 = CFG_CS3_BASE;
 	fbcs->cscr3 = CFG_CS3_CTRL;
 	fbcs->csmr3 = CFG_CS3_MASK;
 #endif
 
 #if (defined(CFG_CS4_BASE) && defined(CFG_CS4_MASK) && defined(CFG_CS4_CTRL))
+	gpio->par_cs |= GPIO_PAR_CS4;
 	fbcs->csar4 = CFG_CS4_BASE;
 	fbcs->cscr4 = CFG_CS4_CTRL;
 	fbcs->csmr4 = CFG_CS4_MASK;
 #endif
 
 #if (defined(CFG_CS5_BASE) && defined(CFG_CS5_MASK) && defined(CFG_CS5_CTRL))
+	gpio->par_cs |= GPIO_PAR_CS5;
 	fbcs->csar5 = CFG_CS5_BASE;
 	fbcs->cscr5 = CFG_CS5_CTRL;
 	fbcs->csmr5 = CFG_CS5_MASK;
@@ -124,3 +115,23 @@ int cpu_init_r(void)
 {
 	return (0);
 }
+
+void uart_port_conf(void)
+{
+	volatile gpio_t *gpio = (gpio_t *) MMAP_GPIO;
+
+	/* Setup Ports: */
+	switch (CFG_UART_PORT) {
+	case 0:
+		gpio->par_uart = (GPIO_PAR_UART_TXD0 | GPIO_PAR_UART_RXD0);
+		break;
+	case 1:
+		gpio->par_uart =
+		    (GPIO_PAR_UART_TXD1(3) | GPIO_PAR_UART_RXD1(3));
+		break;
+	case 2:
+		gpio->par_timer &= 0x0F;
+		gpio->par_timer |= (GPIO_PAR_TIN3_URXD2 | GPIO_PAR_TIN2_UTXD2);
+		break;
+	}
+}
diff --git a/drivers/serial/mcfuart.c b/drivers/serial/mcfuart.c
index 39d4e18..7918036 100644
--- a/drivers/serial/mcfuart.c
+++ b/drivers/serial/mcfuart.c
@@ -34,6 +34,8 @@
 DECLARE_GLOBAL_DATA_PTR;
 
 #ifdef CONFIG_MCFUART
+extern void uart_port_conf(void);
+
 int serial_init(void)
 {
 	volatile uart_t *uart;
@@ -41,6 +43,8 @@ int serial_init(void)
 
 	uart = (volatile uart_t *)(CFG_UART_BASE);
 
+	uart_port_conf();
+	
 	/* write to SICR: SIM2 = uart mode,dcd does not affect rx */
 	uart->ucr = UART_UCR_RESET_RX;
 	uart->ucr = UART_UCR_RESET_TX;
-- 
1.5.2

